@@ -34,8 +34,6 @@ This is useful in fields such as medicine where only partial
 timestamps may be known for certain events.
 """
 #===========================================================================
-# $Id: gmDateTime.py,v 1.34 2009-11-13 21:04:45 ncq Exp $
-# $Source: /home/ncq/Projekte/cvs2git/vcs-mirror/gnumed/gnumed/client/pycommon/gmDateTime.py,v $
 __version__ = "$Revision: 1.34 $"
 __author__ = "K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL (details at http://www.gnu.org)"
@@ -236,10 +234,11 @@ def wxDate2py_dt(wxDate=None):
 		raise
 #---------------------------------------------------------------------------
 def py_dt2wxDate(py_dt=None, wx=None):
-	wxdt = wx.DateTime()
-	wxdt.SetYear(py_dt.year)
-	wxdt.SetMonth(py_dt.month-1)
-	wxdt.SetDay(py_dt.day)
+	_log.debug(u'setting wx.DateTime from: %s-%s-%s', py_dt.year, py_dt.month, py_dt.day)
+	# Robin Dunn says that for SetYear/*Month/*Day the wx.DateTime MUST already
+	# be valid (by definition) or, put the other way round, you must Set() day,
+	# month, and year at once
+	wxdt = wx.DateTimeFromDMY(py_dt.day, py_dt.month-1, py_dt.year)
 	return wxdt
 #===========================================================================
 # interval related
@@ -304,24 +303,25 @@ def format_interval_medically(interval=None):
 	# FIXME: i18n for abbrevs
 
 	# more than 1 year ?
-	if interval.days > 360:
-		years, days = divmod(interval.days, 360)
-		months, day = divmod(days, 30)
-		if months == 0:
+	if interval.days > 363:
+		years, days = divmod(interval.days, 364)
+		leap_days, tmp = divmod(years, 4)
+		months, day = divmod((days + leap_days), 30.33)
+		if int(months) == 0:
 			return "%sy" % int(years)
 		return "%sy %sm" % (int(years), int(months))
 
 	# more than 30 days / 1 month ?
 	if interval.days > 30:
-		months, days = divmod(interval.days, 30)
+		months, days = divmod(interval.days, 30.33)
 		weeks, days = divmod(days, 7)
-		if (weeks + days) == 0:
+		if int(weeks + days) == 0:
 			result = '%smo' % int(months)
 		else:
 			result = '%sm' % int(months)
-		if weeks != 0:
+		if int(weeks) != 0:
 			result += ' %sw' % int(weeks)
-		if days != 0:
+		if int(days) != 0:
 			result += ' %sd' % int(days)
 		return result
 
@@ -346,19 +346,212 @@ def format_interval_medically(interval=None):
 		minutes = seconds // 60
 		if minutes == 0:
 			return '%sh' % int(hours)
-		return "%sh %sm" % (int(hours), int(minutes))
+		return "%s:%02d" % (int(hours), int(minutes))
 
 	# minutes only
 	if interval.seconds > (5*60):
-		return "%smi" % (int(interval.seconds // 60))
+		return "0:%02d" % (int(interval.seconds // 60))
 
 	# seconds
 	minutes, seconds = divmod(interval.seconds, 60)
 	if minutes == 0:
 		return '%ss' % int(seconds)
 	if seconds == 0:
-		return '%smi' % int(minutes)
-	return "%sm %ss" % (int(minutes), int(seconds))
+		return '0:%02d' % int(minutes)
+	return "%s.%ss" % (int(minutes), int(seconds))
+#---------------------------------------------------------------------------
+def calculate_apparent_age(start=None, end=None):
+	"""The result of this is a tuple (years, ..., seconds) as one would
+	'expect' a date to look like, that is, simple differences between
+	the fields.
+
+	No need for 100/400 years leap days rule	because 2000 WAS a leap year.
+
+	This does not take into account time zones which may
+	shift the result by one day.
+
+	<start> and <end> must by python datetime instances
+	<end> is assumed to be "now" if not given
+	"""
+	if end is None:
+		end = pyDT.datetime.now(gmCurrentLocalTimezone)
+
+	if end < start:
+		raise ValueError('calculate_apparent_age(): <end> (%s) before <start> %s' % (end, start))
+
+	if end == start:
+		years = months = days = hours = minutes = seconds = 0
+		return (years, months, days, hours, minutes, seconds)
+
+	# years
+	years = end.year - start.year
+	end = end.replace(year = start.year)
+	if end < start:
+		years = years - 1
+
+	# months
+	if end.month == start.month:
+		months = 0
+	else:
+		months = end.month - start.month
+		if months < 0:
+			months = months + 12
+		if end.day > gregorian_month_length[start.month]:
+			end = end.replace(month = start.month, day = gregorian_month_length[start.month])
+		else:
+			end = end.replace(month = start.month)
+		if end < start:
+			months = months - 1
+
+	# days
+	if end.day == start.day:
+		days = 0
+	else:
+		days = end.day - start.day
+		if days < 0:
+			days = days + gregorian_month_length[start.month]
+		end = end.replace(day = start.day)
+		if end < start:
+			days = days - 1
+
+	# hours
+	if end.hour == start.hour:
+		hours = 0
+	else:
+		hours = end.hour - start.hour
+		if hours < 0:
+			hours = hours + 24
+		end = end.replace(hour = start.hour)
+		if end < start:
+			hours = hours - 1
+
+	# minutes
+	if end.minute == start.minute:
+		minutes = 0
+	else:
+		minutes = end.minute - start.minute
+		if minutes < 0:
+			minutes = minutes + 60
+		end = end.replace(minute = start.minute)
+		if end < start:
+			minutes = minutes - 1
+
+	# seconds
+	if end.second == start.second:
+		seconds = 0
+	else:
+		seconds = end.second - start.second
+		if seconds < 0:
+			seconds = seconds + 60
+		end = end.replace(second = start.second)
+		if end < start:
+			seconds = seconds - 1
+
+	return (years, months, days, hours, minutes, seconds)
+#---------------------------------------------------------------------------
+def format_apparent_age_medically(age=None):
+	"""<age> must be a tuple as created by calculate_apparent_age()"""
+
+	(years, months, days, hours, minutes, seconds) = age
+
+	# more than 1 year ?
+	if years > 1:
+		if months == 0:
+			return u'%s%s' % (
+				years,
+				_('y::year_abbreviation').replace('::year_abbreviation', u'')
+			)
+		return u'%s%s %s%s' % (
+			years,
+			_('y::year_abbreviation').replace('::year_abbreviation', u''),
+			months,
+			_('m::month_abbreviation').replace('::month_abbreviation', u'')
+		)
+
+	# more than 1 month ?
+	if months > 1:
+		if days == 0:
+			return u'%s%s' % (
+				months,
+				_('mo::month_only_abbreviation').replace('::month_only_abbreviation', u'')
+			)
+
+		result = u'%s%s' % (
+			months,
+			_('m::month_abbreviation').replace('::month_abbreviation', u'')
+		)
+
+		weeks, days = divmod(days, 7)
+		if int(weeks) != 0:
+			result += u'%s%s' % (
+				int(weeks),
+				_('w::week_abbreviation').replace('::week_abbreviation', u'')
+			)
+		if int(days) != 0:
+			result += u'%s%s' % (
+				int(days),
+				_('d::day_abbreviation').replace('::day_abbreviation', u'')
+			)
+
+		return result
+
+	# between 7 days and 1 month
+	if days > 7:
+		return u"%s%s" % (
+			days,
+			_('d::day_abbreviation').replace('::day_abbreviation', u'')
+		)
+
+	# between 1 and 7 days ?
+	if days > 0:
+		if hours == 0:
+			return u'%s%s' % (
+				days,
+				_('d::day_abbreviation').replace('::day_abbreviation', u'')
+			)
+		return u'%s%s (%s%s)' % (
+			days,
+			_('d::day_abbreviation').replace('::day_abbreviation', u''),
+			hours,
+			_('h::hour_abbreviation').replace('::hour_abbreviation', u'')
+		)
+
+	# between 5 hours and 1 day
+	if hours > 5:
+		return u'%s%s' % (
+			hours,
+			_('h::hour_abbreviation').replace('::hour_abbreviation', u'')
+		)
+
+	# between 1 and 5 hours
+	if hours > 1:
+		if minutes == 0:
+			return u'%s%s' % (
+				hours,
+				_('h::hour_abbreviation').replace('::hour_abbreviation', u'')
+			)
+		return u'%s:%02d' % (
+			hours,
+			minutes
+		)
+
+	# between 5 and 60 minutes
+	if minutes > 5:
+		return u"0:%02d" % minutes
+
+	# less than 5 minutes
+	if minutes == 0:
+		return u'%s%s' % (
+			seconds,
+			_('s::second_abbreviation').replace('::second_abbreviation', u'')
+		)
+	if seconds == 0:
+		return u"0:%02d" % minutes
+	return "%s.%s%s" % (
+		minutes,
+		seconds,
+		_('s::second_abbreviation').replace('::second_abbreviation', u'')
+	)
 #---------------------------------------------------------------------------
 def str2interval(str_interval=None):
 
@@ -1253,7 +1446,9 @@ if __name__ == '__main__':
 			pyDT.timedelta(days = 365),
 			pyDT.timedelta(days = 366),
 			pyDT.timedelta(days = 367),
-			pyDT.timedelta(days = 400)
+			pyDT.timedelta(days = 400),
+			pyDT.timedelta(weeks = 52 * 30),
+			pyDT.timedelta(weeks = 52 * 79, days = 33)
 		]
 
 		idx = 1
@@ -1338,6 +1533,18 @@ if __name__ == '__main__':
 		print "fts           :", fts
 		print "fts.get_pydt():", fts.get_pydt()
 	#-------------------------------------------------
+	def test_calculate_apparent_age():
+		start = pydt_now_here().replace(year = 1974).replace(month = 10).replace(day = 23)
+		print calculate_apparent_age(start = start)
+		print format_apparent_age_medically(calculate_apparent_age(start = start))
+		start = pydt_now_here().replace(year = 1979).replace(month = 3).replace(day = 13)
+		print calculate_apparent_age(start = start)
+		print format_apparent_age_medically(calculate_apparent_age(start = start))
+
+		start = pydt_now_here().replace(year = 1979).replace(month = 2, day = 2)
+		end = pydt_now_here().replace(year = 1979).replace(month = 3).replace(day = 31)
+		print calculate_apparent_age(start = start, end = end)
+	#-------------------------------------------------
 	if len(sys.argv) > 1 and sys.argv[1] == "test":
 
 		# GNUmed libs
@@ -1352,170 +1559,7 @@ if __name__ == '__main__':
 		#test_get_pydt()
 		#test_str2interval()
 		#test_format_interval()
-		test_format_interval_medically()
+		#test_format_interval_medically()
+		test_calculate_apparent_age()
 
 #===========================================================================
-# $Log: gmDateTime.py,v $
-# Revision 1.34  2009-11-13 21:04:45  ncq
-# - improved medical interval formatting
-#
-# Revision 1.33  2009/11/08 20:43:04  ncq
-# - improved format-interval-medically plus tests
-#
-# Revision 1.32  2009/11/06 15:07:40  ncq
-# - re-formatting for clarity
-# - simplify str2interval regexes
-#
-# Revision 1.31  2009/10/29 17:14:11  ncq
-# - improve (simplify) str2interval
-#
-# Revision 1.30  2009/09/23 14:32:05  ncq
-# - pydt-now-here()
-#
-# Revision 1.29  2009/07/09 16:42:06  ncq
-# - ISO date formatting
-#
-# Revision 1.28  2009/06/04 14:50:06  ncq
-# - re-import lost formatters
-#
-# Revision 1.28  2009/05/28 10:48:29  ncq
-# - format_interval(_medically)
-#
-# Revision 1.27  2009/04/19 22:23:36  ncq
-# - move interval parsers here
-#
-# Revision 1.26  2009/04/03 09:33:22  ncq
-# - conversions for wx.DateTime
-#
-# Revision 1.25  2009/02/05 14:28:30  ncq
-# - comment
-#
-# Revision 1.24  2008/11/17 23:11:38  ncq
-# - provide properly utf8iefied py_*_timezone_name
-#
-# Revision 1.23  2008/11/03 10:28:03  ncq
-# - improved wording
-#
-# Revision 1.22  2008/10/22 12:07:28  ncq
-# - log mx.DateTime version
-# - use %x in strftime
-#
-# Revision 1.21  2008/06/18 15:28:32  ncq
-# - properly i18n trigger chars in str 2 timestamp conversions
-# - document "patterns" arg for str 2 timestamp conversion
-#
-# Revision 1.20  2008/05/19 15:45:26  ncq
-# - re-adjust timezone handling code
-# - remember timezone *name* for PG
-#
-# Revision 1.19  2008/04/12 22:30:46  ncq
-# - support more date/time patterns
-#
-# Revision 1.18  2008/01/13 01:14:26  ncq
-# - does need gmI18N
-#
-# Revision 1.17  2008/01/05 16:37:47  ncq
-# - typo fix
-#
-# Revision 1.16  2007/12/12 16:17:15  ncq
-# - better logger names
-#
-# Revision 1.15  2007/12/11 14:18:20  ncq
-# - stdlib logging
-#
-# Revision 1.14  2007/09/04 23:28:06  ncq
-# - document what's happening
-#
-# Revision 1.13  2007/09/04 21:59:30  ncq
-# - try to work around Windows breakage before 1970
-#
-# Revision 1.12  2007/09/03 12:56:00  ncq
-# - test for dates before 1970
-#
-# Revision 1.11  2007/06/15 08:10:40  ncq
-# - improve test suite
-#
-# Revision 1.10  2007/06/15 08:01:09  ncq
-# - better argument naming
-# - fix regexen for unicode/locale
-#
-# Revision 1.9  2007/05/21 17:13:12  ncq
-# - import gmI18N
-#
-# Revision 1.8  2007/04/23 16:56:54  ncq
-# - poperly place misplaced "
-#
-# Revision 1.7  2007/04/02 18:21:27  ncq
-# - incorporate all of gmFuzzyTimestamp.py
-#
-# Revision 1.6  2007/01/16 17:59:55  ncq
-# - improved docs and tests
-# - normalized UTC offset since time and datetime modules
-#   do not agree sign vs direction
-#
-# Revision 1.5  2007/01/16 13:42:21  ncq
-# - add gmCurrentLocalTimezone() as cFixedOffsetTimezone instance
-#   with values taken from currently applicable UTC offset
-#
-# Revision 1.4  2007/01/10 22:31:10  ncq
-# - add FixedOffsetTimezone() from psycopg2.tz
-#
-# Revision 1.3  2006/12/22 16:54:28  ncq
-# - add cLocalTimezone from psycopg2 until datetime supports it
-# - better logging
-# - enhanced test suite
-#
-# Revision 1.2  2006/12/21 17:44:26  ncq
-# - differentiate between timezone as interval and as string
-# - if timezone string is to be ISO aware it cannot contain ","
-#
-# Revision 1.1  2006/12/21 10:50:50  ncq
-# - date/time handling
-#
-#
-#===========================================================================
-# old Log for gmFuzzyTimestamp.py:
-#
-# Revision 1.11  2007/04/01 15:27:09  ncq
-# - safely get_encoding()
-#
-# Revision 1.10  2007/03/02 15:30:24  ncq
-# - must decode() strftime() output
-#
-# Revision 1.9  2007/02/16 10:20:39  ncq
-# - improved doc strings
-#
-# Revision 1.8  2007/02/16 10:15:27  ncq
-# - strftime() returns str() but encoded, so we need
-#   locale.getlocale()[1] to properly decode that to
-#   unicode, which needs the locale system to have been
-#   initialized
-# - improved test suite
-#
-# Revision 1.7  2007/01/10 22:43:39  ncq
-# - depend on gmDateTime, not gmPG2
-#
-# Revision 1.6  2006/11/27 23:00:45  ncq
-# - add str2fuzzy_timestamp_matches() with all the needed infrastructure
-# - some unicode()ing
-# - user more symbolic names
-#
-# Revision 1.5  2006/11/07 23:49:08  ncq
-# - make runnable standalone for testing
-# - add get_mxdt()/get_pydt()
-#   - but thus requires gmPG2, yuck, work around later
-#
-# Revision 1.4  2006/10/31 17:18:55  ncq
-# - make cFuzzyTimestamp accept datetime.datetime instances, too
-#
-# Revision 1.3  2006/10/25 07:46:44  ncq
-# - Format() -> strftime() since datetime.datetime does not have .Format()
-#
-# Revision 1.2  2006/05/24 09:59:57  ncq
-# - add constants for accuracy values
-# - __init__() now defaults to now()
-# - add accuracy-aware Format()/strftime() proxies
-#
-# Revision 1.1  2006/05/22 12:00:00  ncq
-# - first cut at this
-#
